@@ -1,5 +1,5 @@
 /* vim: set noet ts=4:
- * $Id: wmweather.c,v 1.88 2003/10/26 12:08:11 godisch Exp $
+ * $Id: wmweather.c,v 1.89 2004/07/11 15:34:21 godisch Exp $
  *
  * Copyright (c) 1999 Michael G. Henderson <mghenderson@lanl.gov>.
  * Copyright (c) 2002-2003 Martin A. Godisch <martin@godisch.de>.
@@ -84,6 +84,7 @@ int
 	knots       = 0,
 	mps         = 0,
 	tzone       = -50000,
+	showheat    = 0,
 	showchill   = 0;
 pid_t
 	xmsg_child  = 0;
@@ -303,6 +304,8 @@ static void do_conf(const char *rcfile)
 			mps = 1;
 		} else if (strcmp(buffer, "chill")    == 0) {
 			showchill = 1;
+ 		} else if (strcmp(buffer, "heat")     == 0) {
+ 			showheat = 1;
 		} else if (strcmp(buffer, "utc")      == 0) {
 			tzone = 0;
 		} else if (strcmp(buffer, "time") == 0 && optarg) {
@@ -367,6 +370,7 @@ static void do_opts(int argc, char *argv[])
 		{"knots",      0, NULL, 'n'},
 		{"mps",        0, NULL, 'p'},
 		{"chill",      0, NULL, 'w'},
+		{"heat",       0, NULL, 'e'},
 		{"utc",        0, NULL, 'u'},
 		{"time",       1, NULL, 't'},
 		{"proxy",      1, NULL, 'x'},
@@ -392,7 +396,7 @@ static void do_opts(int argc, char *argv[])
 			mmHg   = 1;
 		}
 	while (1) {
-		if ((i = getopt_long(argc, argv, "s:d:makgbnpwWut:x:U:chv", long_opts, NULL)) == -1)
+		if ((i = getopt_long(argc, argv, "s:d:makgbnpwWeut:x:U:chv", long_opts, NULL)) == -1)
 			break;
 		switch (i) {
 		case 's':
@@ -448,6 +452,9 @@ static void do_opts(int argc, char *argv[])
 		case 'W':
 			showchill = 1;
 			break;
+		case 'e':
+			showheat = 1;
+			break;
 		case 'u':
 			tzone = 0;
 			break;
@@ -486,8 +493,9 @@ static void do_opts(int argc, char *argv[])
 			printf("  -s, --station=<id>    four-letter ICAO location indicator (required),\n");
 			printf("  -c, --compat          use version 1 monitor style, default in wmWeather,\n");
 			printf("  -d, --delay=[@]<min>  update delay, use @ for minutes past the hour,\n");
-			printf("  -m, --metric          display metric values: C, hPa, km/h,\n");
+			printf("  -m, --metric          display metric values: °C, hPa, km/h,\n");
 			printf("  -w, --chill           display wind chill instead of dew point,\n");
+			printf("  -e, --heat            display heat index instead of dew point,\n");
 			printf("  -b, --beaufort        display windspeed in Beaufort,\n");
 			printf("  -n, --knots           display windspeed in knots (seamiles per hour),\n");
 			printf("  -u, --utc             display UTC instead of localtime,\n");
@@ -659,6 +667,7 @@ static void update(int force_read)
 		dewpointavail    = 0,
 		windchill        = 0,
 		windchillavail   = 0,
+		heatindexavail   = 0,
 		humidity         = 0,
 		humidityavail    = 0,
 		pressureavail    = 0,
@@ -670,6 +679,7 @@ static void update(int force_read)
 		showerror        = 1;
 	static double
 		windspeed        = 0,
+		heatindex        = 0,
 		pressure         = 0;
 	static time_t
 		last_report      = 0;
@@ -716,6 +726,8 @@ static void update(int force_read)
 		dewpointavail    = 0;
 		windchill        = 0;
 		windchillavail   = 0;
+		heatindex        = 0;
+		heatindexavail   = 0;
 		humidity         = 0;
 		humidityavail    = 0;
 		pressureavail    = 0;
@@ -864,6 +876,20 @@ static void update(int force_read)
 				continue;
 			}
 
+			if (!strncmp(buffer, "Heat index: ", 12)) {
+				i = buffer + 12;
+				heatindex = strtod(i, &i);
+				if (*i != ' ') {
+					if (showerror)
+						fprintf(stderr, "%s: invalid heat index temperature: %s line %d\n", PACKAGE_NAME, report, line);
+					continue;
+				}
+				heatindexavail = 1;
+				if (metric)
+					heatindex = (heatindex - 32.0) * 5.0 / 9.0 + 0.5;
+				continue;
+			}
+
 			if (!strncmp(buffer, "Temperature: ", 13)) {
 				i = buffer + 13;
 				temperature = strtol(i, &i, 10);
@@ -1174,6 +1200,29 @@ static void update(int force_read)
 				copyXPMArea(121, 0, 9, 7, 49, 24);
 		}
 
+		if (heatindexavail && (showheat || (!showchill && !dewpointavail))) {
+			copyXPMArea(35, 71, 5, 7,  6, 24);
+			copyXPMArea(95, 71, 5, 7, 12, 24);
+			copyXPMArea(40, 71, 5, 7, 18, 24);
+			l = (long)heatindex;
+		} else
+			l = dewpoint;
+		if (heatindexavail || dewpointavail) {
+			if (l < 0) {
+				copyXPMArea(40, 67, 5, 1, (l <= -10) ? 31 : 37, 27);
+				l *= -1;
+			}
+			if (l >= 100)
+				copyXPMArea(l % 1000 / 100 * 5, 64, 5, 7, 31, 24);
+			if (l >=  10)
+				copyXPMArea(l %  100 /  10 * 5, 64, 5, 7, 37, 24);
+			copyXPMArea(l % 10 * 5, 64, 5, 7, 43, 24);
+			if (metric)
+				copyXPMArea(121, 7, 9, 7, 49, 24);
+			else
+				copyXPMArea(121, 0, 9, 7, 49, 24);
+		}
+
 		if (pressureavail) {
 			l = (long)(pressure + 0.5);
 			if (l >= 1000)
